@@ -11,14 +11,14 @@ PXR_NAMESPACE_OPEN_SCOPE
 
 // clang-format off
 TF_DEBUG_CODES(
-    HD_ANARI_GEOMETRY,
-    HD_ANARI_INSTANCER,
-    HD_ANARI_MATERIAL,
-    HD_ANARI_MESH,
-    HD_ANARI_POINTS,
-    HD_ANARI_RENDERDELEGATE,
-    HD_ANARI_RENDERPARAMS,
-    HD_ANARI_RENDERPASS
+    HD_ANARI_RD_GEOMETRY,
+    HD_ANARI_RD_INSTANCER,
+    HD_ANARI_RD_MATERIAL,
+    HD_ANARI_RD_MESH,
+    HD_ANARI_RD_POINTS,
+    HD_ANARI_RD_RENDERDELEGATE,
+    HD_ANARI_RD_RENDERPARAMS,
+    HD_ANARI_RD_RENDERPASS
 );
 //clang-format on
 
