@@ -3,15 +3,17 @@
 
 #pragma once
 
-#include <anari/anari_cpp.hpp>
 #include <pxr/imaging/hio/image.h>
 #include <pxr/usd/sdf/assetPath.h>
+#include <anari/anari_cpp.hpp>
+
+#include <array>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
-
-class HdAnariTextureLoader {
-public:
+class HdAnariTextureLoader
+{
+ public:
   enum class ColorSpace
   {
     Raw,
@@ -24,17 +26,20 @@ public:
     Linear,
   };
 
-  struct TextureDesc {
+  struct TextureDesc
+  {
     std::string assetPath;
     ColorSpace colorspace = ColorSpace::Raw;
     MinMagFilter minMagFilter = MinMagFilter::Linear;
+    // clang-format off
     std::array<float, 16> transform = {
-      1.0f, 0.0f, 0.0, 0.0f,
+      1.0f, 0.0f, 0.0f, 0.0f,
       0.0f, 1.0f, 0.0f, 0.0f,
       0.0f, 0.0f, 1.0f, 0.0f,
       0.0f, 0.0f, 0.0f, 1.0f,
       };
     std::array<float, 4> offset = { 0.0f, 0.0f, 0.0f, 0.0f };
+    // clang-format on
   };
 
   static anari::DataType HioFormatToAnari(HioFormat f);
@@ -43,7 +48,6 @@ public:
       const std::string &file,
       MinMagFilter minMagFilter,
       ColorSpace colorspace);
-
 };
 
 PXR_NAMESPACE_CLOSE_SCOPE
